Rewrite of language strings
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index dbbff4b257a41a5bf132fc18bb861edfa7f30d43..a36ed185285f60f946f4f02970db5fc8f0dd6f33 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -1,18 +1,23 @@
 <?php
 /************************************************************************
- * MXChange v0.2.1                                    Start: 10/13/2003 *
- * ===============                              Last change: 09/04/2004 *
+ * Mailer v0.2.1-FINAL                                Start: 10/13/2003 *
+ * ===================                          Last change: 09/04/2004 *
  *                                                                      *
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
- *                                                                      *
+ * $Revision::                                                        $ *
+ * $Date::                                                            $ *
+ * $Tag:: 0.2.1-FINAL                                                 $ *
+ * $Author::                                                          $ *
+ * Needs to be in all Files and every File needs "svn propset           *
+ * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
  * -------------------------------------------------------------------- *
- * Copyright (c) 2003 - 2008 by Roland Haeder                           *
+ * Copyright (c) 2003 - 2009 by Roland Haeder                           *
  * For more information visit: http://www.mxchange.org                  *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * MA  02110-1301  USA                                                  *
  ************************************************************************/
 
-// Load security stuff here (Oh, I hope this is not unsecure? Am I paranoia??? ;-) )
-require_once("inc/libs/security_functions.php");
-
-// Init "action" and "what"
-global $what, $action;
-$GLOBALS['what'] = ""; $GLOBALS['action'] = "";
+// Load security stuff here
+require('inc/libs/security_functions.php');
 
 // Set module
-$GLOBALS['module'] = "ref"; $CSS = -1;
+$GLOBALS['module'] = 'ref';
+$GLOBALS['output_mode'] = -1;
 
 // Load the required file(s)
-require ("inc/config.php");
-
-// Redirect only to registration page when this script is installed
-if (defined('mxchange_installed') && (isBooleanConstantAndTrue('mxchange_installed'))) {
-       // Base URL for redirection
-       switch ($_CONFIG['refid_target'])
-       {
-       case "register":
-               $URL = URL."/modules.php?module=index&what=register&refid=";
-               break;
+require('inc/config-global.php');
 
-       case "index":
-               $URL = URL."/index.php?refid=";
-               break;
-       }
+// No refid by default
+$URL = 'index.php';
 
-       // Get referral ID from ref or refid variable
-       if (!empty($_GET['ref']))        $ref = secureString($_GET['ref']);
-        elseif (!empty($_GET['refid'])) $ref = secureString($_GET['refid']);
+if (determineReferalId() > 0) {
+       // Test if nickname or numeric id
+       if (isExtensionActive('nickname')) {
+               // Nickname in URL, so load the id
+               fetchUserData(determineReferalId(), 'nickname');
 
-       if (!empty($ref)) {
-               // Test if nickname or numeric id
-               if ((EXT_IS_ACTIVE("nickname")) && ($ref != "".bigintval($ref)."")) {
-                       // Nickname in URL, so load the ID
-                       $result = SQL_QUERY_ESC("SELECT userid FROM "._MYSQL_PREFIX."_user_data WHERE nickname='%s' LIMIT 1",
-                               array($ref), __FILE__, __LINE__);
-                       list($ref) = SQL_FETCHROW($result);
-                       SQL_FREERESULT($result);
-               } // END - if
+               // Do we have an entry?
+               if (isUserDataValid()) {
+                       // Load userid
+                       $GLOBALS['refid'] = getUserData('userid');
+               } else {
+                       // So do we have a userid?
+                       fetchUserData(determineReferalId());
 
-               // Also edit this 0 !
-               if (empty($ref)) $ref = 0;
+                       // Do we have an entry?
+                       if (!isUserDataValid()) {
+                               // No entry, so no referal id
+                               $GLOBALS['refid'] = getConfig('def_refid');
+                       } // END - if
+               }
+       } // END - if
 
-               // We have an refid here. So we simply add it
-               $URL .= bigintval($ref);
+       // Update session
+       setSession('refid', determineReferalId());
 
+       // Is the refid valid?
+       if (determineReferalId() > 0) {
                // Update ref counter
-               $result = SQL_QUERY_ESC("UPDATE "._MYSQL_PREFIX."_user_data SET ref_clicks=ref_clicks+1 WHERE userid=%s LIMIT 1",
-                       array(bigintval($ref)), __FILE__, __LINE__);
-       } else {
-               // No refid and we add our refid (don't forget to set $def_refid!)
-               $URL = URL."/index.php";
-       }
+               SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
+                       array(determineReferalId()), __FILE__, __LINE__);
+
+               // Base URL for redirection
+               switch (getConfig('refid_target')) {
+                       case 'register':
+                               $URL = 'modules.php?module=index&amp;what=register';
+                               break;
+
+                       case 'index':
+                               $URL = 'index.php';
+                               break;
+               } // END - switch
+       } // END - if
+} // END - if
 
-       // Load the URL
-       LOAD_URL($URL);
-} else {
-       // You have to configure first!
-       LOAD_URL("install.php");
-}
+// Load the URL
+redirectToUrl($URL);
 
-// Really all done here... ;-)
+// [EOF]
 ?>
@@ -1,18 +1,23 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referral link                *
+ * Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
@@ -1,18 +1,23 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *